package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.GetMapping;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.domain.SysNotice;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISysNoticeService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/notice" })
public class SysNoticeController extends BaseController
{
    @Autowired
    private ISysNoticeService noticeService;
    
    @GetMapping({ "/list" })
    public TableDataInfo list(final SysNotice notice) {
        this.startPage();
        final List<SysNotice> list = this.noticeService.selectNoticeList(notice);
        return this.getDataTable((List)list);
    }
    
    @RequiresPermissions({ "system:notice:query" })
    @GetMapping({ "/{noticeId}" })
    public AjaxResult getInfo(@PathVariable final Long noticeId) {
        return this.success((Object)this.noticeService.selectNoticeById(noticeId));
    }
    
    @RequiresPermissions({ "system:notice:add" })
    @Log(title = "通知公告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody final SysNotice notice) {
        notice.setCreateBy(SecurityUtils.getUsername());
        return this.toAjax(this.noticeService.insertNotice(notice));
    }
    
    @RequiresPermissions({ "system:notice:edit" })
    @Log(title = "通知公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody final SysNotice notice) {
        notice.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.noticeService.updateNotice(notice));
    }
    
    @RequiresPermissions({ "system:notice:remove" })
    @Log(title = "通知公告", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{noticeIds}" })
    public AjaxResult remove(@PathVariable final Long[] noticeIds) {
        return this.toAjax(this.noticeService.deleteNoticeByIds(noticeIds));
    }
}
